@@ -206,6 +206,8 @@ class CustomCocoDataset(Dataset):
             if 'boxes' in target:
                 target['boxes'] = torch.tensor(target['boxes'], dtype=torch.float)
                 target['labels'] = torch.tensor(target['labels'], dtype=torch.int64)
+            if 'kps' in target:
+                target['kps'] = torch.tensor(target['kps'], dtype=torch.float)
             target['size'] = torch.tensor(target['size'], dtype=torch.float)  # file尺寸
 
         # 每个图片对应的target数量是不一致的 所以需要用target封装
