@@ -98,11 +98,11 @@ def ftransform_ssd_train(size_wh_input, is_multi_scale=None, multi_scale_val=Non
     ])
 
 
-def ftransform_cpm_train(size_wh_input, is_multi_scale=None, multi_scale_val=None):
+def ftransform_cpm_train(size_wh_input, mirror_name, is_multi_scale=None, multi_scale_val=None, ):
     return FCompose([
         FRandomRotate(40),
         FRandomSampleCrop(),
-        FRandomMirror(KEYPOINTS_Mirror['lsp']),
+        FRandomMirror(KEYPOINTS_Mirror[mirror_name]),
         FResize(size_wh_input, is_multi_scale, multi_scale_val),
         Normalize(),
         ConvertColor(current='BGR', transform='RGB'),
