@@ -3,29 +3,26 @@ import os
 from ftools.ai.datas.coco.coco_api import f_look_coco_type, f_coco_verify_info
 from ftools.ai.datas.data_factory import fcre_dataload
 from ftools.ai.gpu.webapi.translate import translate_baidu
+from ftools.ai.picture.f_show import f_show_kp_np4cv
 
 KEYPOINTS_Mirror = {  # 水平翻转 这个要和数据遍历对起
-    'face98': {
-        0: 32, 1: 31, 2: 30, 3: 29, 4: 28, 5: 27, 6: 26, 7: 25, 8: 24, 9: 23, 10: 22, 11: 21, 12: 20,
-        13: 19,
-        14: 18,
-        15: 17,
-        16: 16, 17: 15, 18: 14, 19: 13, 20: 12, 21: 11, 22: 10, 23: 9, 24: 8, 25: 7, 26: 6, 27: 5,
-        28: 4, 29: 3,
-        30: 2,
-        31: 1, 32: 0,
-        33: 46, 34: 45, 35: 44, 36: 43, 37: 42, 38: 50, 39: 49, 40: 48, 41: 47,
-        46: 33, 45: 34, 44: 35, 43: 36, 42: 37, 50: 38, 49: 39, 48: 40, 47: 41,
-        60: 72, 61: 71, 62: 70, 63: 69, 64: 68, 65: 75, 66: 74, 67: 73,
-        72: 60, 71: 61, 70: 62, 69: 63, 68: 64, 75: 65, 74: 66, 73: 67,
-        96: 97, 97: 96,
-        51: 51, 52: 52, 53: 53, 54: 54,
-        55: 59, 56: 58, 57: 57, 58: 56, 59: 55,
-        76: 82, 77: 81, 78: 80, 79: 79, 80: 78, 81: 77, 82: 76,
-        87: 83, 86: 84, 85: 85, 84: 86, 83: 87,
-        88: 92, 89: 91, 90: 90, 91: 89, 92: 88,
-        95: 93, 94: 94, 93: 95
-    },
+    'face98': [[32, 31], [30, 29], [28, 27],
+               [26, 25], [24, 23], [22, 21],
+               [20, 19], [18, 17], [16, 15],
+               [14, 13], [12, 11], [10, 9],
+               [8, 7], [6, 5], [4, 3],
+               [2, 1], [0, 46], [45, 44],
+               [43, 42], [50, 49], [48, 47],
+               [37, 36], [35, 34], [33, 41],
+               [40, 39], [38, 51], [52, 53],
+               [54, 59], [58, 57], [56, 55],
+               [72, 71], [70, 69], [68, 75],
+               [74, 73], [64, 63], [62, 61],
+               [60, 67], [66, 65], [82, 81],
+               [80, 79], [78, 77], [76, 87],
+               [86, 85], [84, 83], [92, 91],
+               [90, 89], [88, 95], [94, 93],
+               [97, 96], ],
     'face5': [[0, 5], [3, 4]],  # widerface
     'lsp': [[0, 5], [1, 4], [2, 3], [6, 11], [7, 10], [8, 9]],  # 14个关键点
 }
@@ -527,21 +524,31 @@ if __name__ == '__main__':
     cfg.SIZE_WH_INPUT_TRAIN = (320, 320)
     cfg.IS_MOSAIC = False
     cfg.IS_MIXUP = False
+    cfg.IS_JUMP = False
+    cfg.IS_DEBUG = False
     cfg.IS_MOSAIC_FILTER = False
     cfg.THR_WH = 5
     cfg.THR_AREA = 25
     cfg.NUM_WORKERS = 0
     mode_train = 'keypoints'  # bbox segm keypoints caption
     # get_data_widerface 数据中自带校验方法
-    data_info, dataloader_train, dataloader_test = get_data_lsp(cfg, path_host=path_host,
-                                                                mode_train=mode_train,
-                                                                batch_train=10)
+    data_info, dataloader_train, dataloader_test = get_data_face98(cfg, path_host=path_host,
+                                                                   mode_train=mode_train,
+                                                                   batch_train=10)
 
     dataset = dataloader_train.dataset
     ids_classes = dataset.ids_classes
 
     for data in dataset:
-        data1 = data
+        img_np, target = data
+        # np(1024, 1024, 3) ， target
+        f_show_kp_np4cv(img_np,
+                        p_kps_l=target['kps'],
+                        kps_seq=None,
+                        g_ltrb=target['boxes'],
+                        is_color_same=True,
+                        )
+        # data1 = data
         pass
 
     ''' ------------------------------- 创建文件 ------------------------------- '''
