@@ -156,7 +156,9 @@ class FitExecutorBase:
             save_val = None  # loss 值 用于保存weight 时记录
             ''' ------------------- 训练代码  --------------------- '''
             if self.dataloader_train is not None and self.cfg.IS_TRAIN:
-                self.model.train()
+                if isinstance(self.model, nn.Module):
+                    # 有时间 model可能 是list
+                    self.model.train()
                 if self.cfg.NUMS_LOCK_WEIGHT_DICT is not None:
                     _mask = self.cfg.NUMS_LOCK_WEIGHT_DICT == epoch  # 这里只用结果的第一个
                     if _mask.any():
